#' @title ExampleGatm
#'
#' @description
#' Example of a grade and tonnage model that is used in MapMark4. The
#' resources are copper and gold.
#'
#' @format
#' The format is described in the package User's Guide.
#'
#' @details
#' This data set is computer-generated. It comprises ore tonnage
#' (in metric tons), copper (Cu) grade (in percent), and
#' gold (Au) grade (in percent) from 71 discovered deposits.
#'
"ExampleGatm"

#' @title ExampleTm
#'
#' @description
#' Example of a tonnage model that is used in MapMark4. The contained metal
#' is uranium (U).
#'
#' @format
#' The format is described in the package User's Guide.
#'
#' @details
#' This data set is computer-generated. It comprises contained metal tonnages
#' (in metric tons) from 53 discovered deposits.
#'
"ExampleTm"

#' @title ExampleDepEst1
#'
#' @description
#' Example of estimates of the number of undiscovered
#' deposits that are generated by geoscientists on a assessment team.
#' These estimates are used within MapMark4 to generate the probability mass
#' function for the number of undiscovered deposits.
#'
#' @format
#' The format is described in the package User's Guide.
#'
#' @details
#' This table is extracted from Table H1 of Zientek (2014, p. 161).
#' The extracted part pertains to the southern carbonate ecaille tract.
#'
#' @references
#' Zientek, M.L., Bliss, J.D., Broughton, D.W., Christie, Michael,
#' Denning, P.D., Hayes, T.S., Hitzman, M.W., Horton, J.D.,
#' Frost-Killian, Susan, Jack, D.J., Master, Sharad, Parks, H.L.,
#' Taylor, C.D., Wilson, A.B., Wintzer, N.E., and Woodhead, Jon,
#' 2014, Sediment-Hosted stratabound copper assessment of the Neoproterozoic
#' Roan Group, Central African Copperbelt, Katanga Basin, Democratic Republic
#' of the Congo and Zambia: U.S. Geological Survey Scientific Investigations
#' Report 2010-5090-T, 162 p., and spatial data,
#' http://dx.doi.org/10.3133/sir20105090T.
#'
"ExampleDepEst1"

#' @title ExampleDepEst2
#'
#' @description
#' Example of estimates of the number of undiscovered
#' deposits that are generated by geoscientists on a assessment team.
#' These estimates are used within MapMark4 to generate the probability mass
#' function for the number of undiscovered deposits.
#'
#' @format
#' The format is described in the package User's Guide.
#'
#' @details
#' This table is extracted from Table H1 of Zientek (2014, p. 161).
#' The extracted part pertains to the central carbonate ecaille tract.
#'
#' @references
#' Zientek, M.L., Bliss, J.D., Broughton, D.W., Christie, Michael,
#' Denning, P.D., Hayes, T.S., Hitzman, M.W., Horton, J.D.,
#' Frost-Killian, Susan, Jack, D.J., Master, Sharad, Parks, H.L.,
#' Taylor, C.D., Wilson, A.B., Wintzer, N.E., and Woodhead, Jon,
#' 2014, Sediment-Hosted stratabound copper assessment of the Neoproterozoic
#' Roan Group, Central African Copperbelt, Katanga Basin, Democratic Republic
#' of the Congo and Zambia: U.S. Geological Survey Scientific Investigations
#' Report 2010-5090-T, 162 p., and spatial data,
#' http://dx.doi.org/10.3133/sir20105090T.
#'
"ExampleDepEst2"

#' @title ExampleDepEst3
#'
#' @description
#' Example of estimates of the number of undiscovered
#' deposits that are generated by geoscientists on a assessment team.
#' These estimates are used within MapMark4 to generate the probability mass
#' function for the number of undiscovered deposits.
#'
#' @format
#' The format is described in the package User's Guide.
#'
#' @details
#' This table is extracted from Table H1 of Zientek (2014, p. 161).
#' The extracted part pertains to the northern carbonate ecaille tract.
#'
#' @references
#' Zientek, M.L., Bliss, J.D., Broughton, D.W., Christie, Michael,
#' Denning, P.D., Hayes, T.S., Hitzman, M.W., Horton, J.D.,
#' Frost-Killian, Susan, Jack, D.J., Master, Sharad, Parks, H.L.,
#' Taylor, C.D., Wilson, A.B., Wintzer, N.E., and Woodhead, Jon,
#' 2014, Sediment-Hosted stratabound copper assessment of the Neoproterozoic
#' Roan Group, Central African Copperbelt, Katanga Basin, Democratic Republic
#' of the Congo and Zambia: U.S. Geological Survey Scientific Investigations
#' Report 2010-5090-T, 162 p., and spatial data,
#' http://dx.doi.org/10.3133/sir20105090T.
#'
"ExampleDepEst3"

#' @title ExampleDepEst4
#'
#' @description
#' Example of estimates of the number of undiscovered
#' deposits that are generated by geoscientists on a assessment team.
#' These estimates are used within MapMark4 to generate the probability mass
#' function for the number of undiscovered deposits.
#'
#' @format
#' The format is described in the package User's Guide.
#'
#' @details
#' This table is extracted from Table H1 of Zientek (2014, p. 161).
#' The extracted part pertains to the ore shale tract.
#'
#' @references
#' Zientek, M.L., Bliss, J.D., Broughton, D.W., Christie, Michael,
#' Denning, P.D., Hayes, T.S., Hitzman, M.W., Horton, J.D.,
#' Frost-Killian, Susan, Jack, D.J., Master, Sharad, Parks, H.L.,
#' Taylor, C.D., Wilson, A.B., Wintzer, N.E., and Woodhead, Jon,
#' 2014, Sediment-Hosted stratabound copper assessment of the Neoproterozoic
#' Roan Group, Central African Copperbelt, Katanga Basin, Democratic Republic
#' of the Congo and Zambia: U.S. Geological Survey Scientific Investigations
#' Report 2010-5090-T, 162 p., and spatial data,
#' http://dx.doi.org/10.3133/sir20105090T.
#'
"ExampleDepEst4"
