% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GradePdf.R
\name{GradePdf}
\alias{GradePdf}
\title{Construct the pdf that represents the resource grades}
\usage{
GradePdf(gatm, seed = NULL, pdfType = "normal", isTruncated = FALSE,
  minNDeposits = 20, nRandomSamples = 1e+06)
}
\arguments{
\item{gatm}{Dataframe containing the grade and tonnage model (gatm). (See details.)}

\item{seed}{Seed for the random number generator.}

\item{pdfType}{Character string containing the type of pdf for the grades.
The choices are either "kde" or "normal".}

\item{isTruncated}{Logical variable indicating whether the pdf is
truncated at the lowest and highest values of the grades in the grade
and tonnage model.}

\item{minNDeposits}{Minimum number of deposits in the grade and tonnage model.}

\item{nRandomSamples}{Number of random samples used to compute summary statistics.
It should be a large value
to ensure that the summary statistics are precise.}
}
\value{
A list with the following components is returned.

\item{gatm}{Input argument gatm.}

\item{seed}{Input argument seed.}

\item{pdfType}{Input argument pdfType.}

\item{isTruncated}{Input argument isTruncated.}

\item{grades}{Grades from the gatm that have been scaled to be
between 0 and 1. The grade of the gangue has been appended.}

\item{resourceNames}{Names of the resources.}

\item{theGatmMean}{Compositional mean for the grades.}

\item{theGatmVar}{Variation matrix for the grades.}

\item{rs}{Random samples of the pdf.}

\item{theMean}{Compositional mean for the pdf.}

\item{theVar}{Variation matrix for the pdf.}

\item{call}{Function call.}
}
\description{
Construct the probability density function (pdf) that
represents the resource grades.
The pdf is not explicitly specified; instead it is implicitly
specified with the random samples that are generated from it.
}
\details{
Data frame gatm comprises the ore tonnages and the grades for the
deposits listed in the grade and tonnage model.
Each row comprises the data for one deposit.
The first column lists a unique identifier for each deposit.
The second column lists the names of the deposits.
The third column lists the ore tonnage.
The fourth and subsequent columns, if any, list
the grades for the resources. The grades are specified in percent.
Grades must not be missing, must be greater than zero, and less than 100.
The minimum number of
deposits (that is, rows in the data frame) should be greater than or
equal to 20.

The columns of the data frame must have headings.
The heading for the first column is "ID".
The heading for the
second column is "Name" or "Deposit name".
The heading for the third column is Ore.
The headings for the fourth and subsequent columns, if any, are the
names of the resources. For example, they might be "Au" and "Cu".

If the \code{pdfType} is \code{kde}, then
a multivariate kernel density estimate
of the ilr-transformed grades is used to
generate ilr-transformed random samples
(Duong, 2007; Hastie and others, 2009, p. 208-209;
Shalizi, 2016, p. 308-330). (ilr refers to isometric log-ratio
transformation (Pawlowsky-Glahn and others, 2015, p. 37).)
In contrast, if the \code{pdfType} is \code{normal},
then a multivariate normal distribution is used to generate
ilr-transformed random samples. For both cases,
the ilr-transformed random samples are converted to random samples of
grade with the inverse ilr transformation.
}
\examples{
gradePdf1 <- GradePdf1(ExampleGatm)

}
\references{
Duong, Tarn, 2007, ks - Kernel density estimation and kernel discriminant
analysis for multivariate data in R: Journal of Statistical Software,
v. 21, issue 7, \url{http://www.jstatsoft.org/}

Hastie, Tevor, Tibshirani, Robert, and Friedman, Jerome, 2009,
The elements of statistical learning - Data mining, inference, and
prediction (2nd ed.): New York, Springer Science + Business Media, LLC, 745 p.

Pawlowsky-Glahn, V., Egozcue, J.J., and Tolosana-Delgado, R., 2015, Modeling
and analysis of compostional data: Chichester, United Kindom, John Wiley &
Sons, Ltd., 247 p.

Shalizi, C.R., 2016, Advanced data analysis from an elementary point of
view: Draft book manuscript publicly available at
\url{http://www.stat.cmu.edu/~cshalizi/ADAfaEPoV/}
}

