% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Simulation.R
\name{Simulation}
\alias{Simulation}
\title{Simulate undiscovered deposits in the permissive tract}
\usage{
Simulation(oPmf, oTonPdf, oGradePdf, seed = NULL, nSimulations = 20000)
}
\arguments{
\item{oPmf}{An object of class "NDepositsPmf"}

\item{oTonPdf}{An object of class "TonnagePdf"}

\item{oGradePdf}{An object of class "GradePdf"}

\item{seed}{Seed for the random number generator.}

\item{nSimulations}{Number of simulations}
}
\value{
A list with the following components is returned.

\item{deposits}{Matrix comprising the simulated undiscovered
deposits. The first column contains the simulation index. (The last index
may not equal argument \code{nSimulations}, but it should be very close.)
The second column contains the number of deposits for the current simulation
index. The third column contains the deposit number (which is called the
"sim deposit index") for the
current number of deposits. The fourth column contains the tonnage for
the current deposit. If the argument oGradePdf is included in the function
call, then the fifth and subsequent columns contain the resource and gangue
grades for the current deposit.}

\item{call}{Function call}
}
\description{
Simulate undiscovered deposits in the permissive tract
}
\details{
The random samples are computed using the algorithm described in
Ellefsen (2017).
}
\examples{
oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst1))
oTonPdf <- TonnagePdf(ExampleGatm)
oGradePdf <- GradePdf(ExampleGatm)
oDeposits <- Simulation(oPmf, oTonPdf, oGradePdf)

oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst1))
oTonPdf <- TonnagePdf(ExampleTm)
oDeposits <- Simulation(oPmf, oTonPdf)

}
\references{
Ellefsen, K.J.,
2017, Probability calculations for three-part mineral resource assessments,
U.S. Geological Survey Report Techniques and Methods XXXX, XX p.
}

