% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TonnagePdf.R
\name{TonnagePdf}
\alias{TonnagePdf}
\title{Construct the pdf that represents the tonnages}
\usage{
TonnagePdf(model, seed = NULL, pdfType = "normal", isTruncated = FALSE,
  minNDeposits = 20, nRandomSamples = 1e+06)
}
\arguments{
\item{model}{Dataframe containing either the grade and tonnage model or the tonnage
model. (See details.)}

\item{seed}{Seed for the random number generator.}

\item{pdfType}{Character string containing the type of pdf for
the log-transformed material tonnages. The choices are either
"kde" or "normal".}

\item{isTruncated}{Logical variable indicating whether the pdf is
truncated at the lowest and highest values of the actual tonnages in the
model.}

\item{minNDeposits}{Minimum number of deposits in the grade and tonnage model.}

\item{nRandomSamples}{Number of random samples used to compute summary statistics.
It should be a large value
to ensure that the summary statistics are precise.}
}
\value{
A list with the following components is returned.

\item{model}{Input argument model.}

\item{seed}{Input argument seed.}

\item{pdfType}{Input argument pdfType.}

\item{isTruncated}{Input argument isTruncated.}

\item{logTonnages}{Vector with the natural logarithm
of the tonnages in the model.}

\item{theModelMean}{Mean of the tonnages in the model.}

\item{theModelSd}{Standard deviation of the tonnages in the
model.}

\item{rs}{Random samples of the pdf.}

\item{theMean}{Mean for the pdf.}

\item{theSd}{Standard deviation for the pdf.}

\item{deviance}{Deviance measuring the relative fit of
the pdf.}

\item{call}{Function call.}
}
\description{
Construct the probability density function (pdf)
that represents the tonnages, which are either ore tonnages in a
grade and tonnage model or contained metal tonnages in a tonnage model.
The pdf is not explicitly specified; instead it is implicitly
specified with the random samples that are generated from it.
}
\details{
If argument model is a grade and tonnage model, then argument model
comprises the ore tonnages and the grades for its deposits.
Each row comprises the data for one deposit.
The first column lists a unique identifier for each deposit.
The second column lists the names of the deposits.
The third column lists the ore tonnage.
The fourth and subsequent columns, if any, list
the grades for the resources.
Ore tonnages must not be missing and must be greater than zero.
The minimum number of
deposits (that is, rows in the data frame) should be greater than or
equal to 20.

The columns of the data frame must have headings.
The heading for the first column is "ID".
The heading for the
second column is "Name" or "Deposit name".
The heading for the third column is Ore.
The headings for the fourth and subsequent columns, if any, are the
names of the resources. For example, they might be "Au" and "Cu".

If argument model is a tonnage model, then argument model comprises just the
contained metal tonnages
for its deposits. The structure of the tonnage model is identical to that
of a grade and tonnage model, with two exceptions. First, the column heading
for the tonnage is appropriate for the model. For example, the heading
could be \"Uranium\". Second, tonnage model lacks columns with grades.

If the \code{pdfType} is \code{kde}, then
a univariate kernel density estimate
of the log-transformed, tonnages is used to
generate log-transformed random samples of tonnage
(Hastie and others, 2009, p. 208-209;
Shalizi, 2016, p. 308-330).
In contrast, if the \code{pdfType} is \code{normal},
then a normal distribution is used to generate
log-transformed random samples of tonnage. For both cases,
the log-transformed random samples are converted to random samples of
tonnage with exponentiation.

The misfit between the actual tonnages in the model and
the pdf that represents those tonnages is quantified with the
deviance (McElreath, 2016, p. 177-182).
}
\examples{
tonPdf <- TonnagePdf(ExampleGatm)

}
\references{
Hastie, Tevor, Tibshirani, Robert, and Friedman, Jerome, 2009,
The elements of statistical learning - Data mining, inference, and
prediction (2nd ed.): New York, Springer Science + Business Media, LLC, 745 p.

McElreath, Richard, 2016, Statistical rethinking - A Bayesian course
with examples in R and Stan: New York, CRC Press, 469 p.

Shalizi, C.R., 2016, Advanced data analysis from an elementary point of
view: Draft book manuscript publicly available at
\url{http://www.stat.cmu.edu/~cshalizi/ADAfaEPoV/}
}

