% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TotalTonnagePdf.R
\name{TotalTonnagePdf}
\alias{TotalTonnagePdf}
\title{Construct the pdf for the total ore and resource tonnages in
all undiscovered deposits within the permissive tract}
\usage{
TotalTonnagePdf(oSimulation, oPmf, oTonPdf, oGradePdf)
}
\arguments{
\item{oSimulation}{An object of class "Simulation"}

\item{oPmf}{An object of class "NDepositsPmf"}

\item{oTonPdf}{An object of class "TonnagePdf"}

\item{oGradePdf}{An object of class "GradePdf"}
}
\value{
A list with the following components is returned.

\item{rs}{Matrix comprising the random samples of
the total ore and resource tonnages in all undiscovered deposits
in the permissive tract.}

\item{theMean}{Mean vector of the total tonnages.}

\item{theSd}{Standard deviation vector of the total tonnages.}

\item{theCorr}{Correlation matrix of the total tonnages.}

\item{thePredMean}{Predicted mean vector of the total tonnages.}

\item{thePredSd}{Predicted standard deviation vector of the
total tonnages.}

\item{thePredCorre}{Predicted correlation matrix of the total
tonnages.}

\item{call}{Function call}
}
\description{
Construct the probability density function (pdf) for the
total ore and resource tonnages in all undiscovered deposits within
the permissive
tract. The pdf is not explicitly specified; instead it is implicitly
specified with the random samples.
}
\details{
The pdf is constructed from the simulated deposits that are stored in
oSimulation.

In addition to constructing the pdf, its mean vector, its standard
deviation vector, and its correlation correlation matrix are calculated.
To check the pdf, a predicted mean vector, a predicted standard devation
vector, and a predicted correlation matrix are calculated with
analytic formulas.
}
\examples{
oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleGatm)
oGradePdf <- GradePdf(ExampleGatm)
oSimulation <- Simulation(oPmf, oTonPdf, oGradePdf)
oTotalTonPdf <- TotalTonnagePdf(oSimulation, oPmf, oTonPdf, oGradePdf)

oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleTm)
oSimulation <- Simulation(oPmf, oTonPdf)
oTotalTonPdf <- TotalTonnagePdf(oSimulation, oPmf, oTonPdf)

}
\references{
Ellefsen, K.J., Phillips, J.D.,
2017, Probability calculations for three-part mineral resource assessments,
U.S. Geological Survey Report Techniques and Methods XXXX, XX p.
}

