% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GradePdf.R
\name{getRandomSamples.GradePdf}
\alias{getRandomSamples.GradePdf}
\title{Generate random samples from the pdf that represents the
grades}
\usage{
\method{getRandomSamples}{GradePdf}(object, nSamples, seed = NULL)
}
\arguments{
\item{object}{An object of class "GradePdf"}

\item{nSamples}{Integer specifying the number of random samples}

\item{seed}{Integer containing the seed.}
}
\value{
Matrix containing random samples from the pdf that represents
the grades for one undiscovered deposit in the permissive
tract.
}
\description{
Generate random samples from the probability density function
(pdf) that represents the grades
}
\details{
To generate random samples, the grades (from the grade and tonnage
model) are
transformed with the isometric log-ratio transform (Pawlowsky-Glahn, and
others, 2015, p. 37).
If the item \code{pdfType} within \code{object} is \code{kde}, then
a kernel density estimate
of the ilr-transformed grades is used to
generate ilr-transformed random samples
(Duong, 2007; Hastie and others, 2009, p. 208-209;
Shalizi, 2016, p. 308-330).
In contrast, if the itme \code{pdfType} is \code{normal},
then a normal distribution is used to generate
ilr-transformed random samples.

The ilr-transformed random samples are converted to random samples of
grade with the inverse ilr-transform.
}
\examples{
gradePdf1 <- GradePdf1(ExampleGatm)
rs <- getRandomSamples(gradePdf1, 2518)

}
\references{
Duong, Tarn, 2007, ks - Kernel density estimation and kernel discriminant
analysis for multivariate data in R: Journal of Statistical Software,
v. 21, issue 7, \url{http://www.jstatsoft.org/}

Hastie, Tevor, Tibshirani, Robert, and Friedman, Jerome, 2009,
The elements of statistical learning - Data mining, inference, and
prediction (2nd ed.): New York, Springer Science + Business Media, LLC, 745 p.

Pawlowsky-Glahn, V., Egozcue, J.J., and Tolosana-Delgado, R., 2015, Modeling
and analysis of compostional data: Chichester, United Kindom, John Wiley &
Sons, Ltd., 247 p.

Shalizi, C.R., 2016, Advanced data analysis from an elementary point of
view: Draft book manuscript publicly available at
\url{http://www.stat.cmu.edu/~cshalizi/ADAfaEPoV/}
}

