% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TonnagePdf.R
\name{getRandomSamples.TonnagePdf}
\alias{getRandomSamples.TonnagePdf}
\title{Generate random samples from the pdf that represents the tonnage}
\usage{
\method{getRandomSamples}{TonnagePdf}(object, nSamples, seed = NULL,
  log_rs = FALSE)
}
\arguments{
\item{object}{An object of class "TonnagePdf"}

\item{nSamples}{Integer specifying the number of random samples}

\item{seed}{Integer containing the seed.}

\item{log_rs}{Logical variable indicating whether the random sample are transformed
with the natural logarithm.}
}
\value{
Vector containing random samples from the pdf that represents the
tonnages for one undiscovered deposit in the permissive tract.
}
\description{
Generate random samples from the probability density
function (pdf) that represents the tonnage.
}
\details{
To generate random samples, the tonnages (from the model) are
transformed with the natural logarithm.
If the \code{pdfType} within \code{object} is \code{kde}, then
a kernel density estimate
of the log-transformed tonnages is used to
generate log-transformed random samples
(Hastie and others, 2009, p. 208-209;
Shalizi, 2016, p. 308-330).
In contrast, if the \code{pdfType} is \code{normal},
then a normal distribution is used to generate
log-transformed random samples.

The log-transformed random samples are converted to random samples of
tonnage with exponentiation.
}
\examples{
oTonPdf <- TonnagePdf(ExampleGatm)
rs <- getRandomSamples(oTonPdf, 2518)

oTonPdf <- TonnagePdf(ExampleTm)
rs <- getRandomSamples(oTonPdf, 2518)

}
\references{
Hastie, Tevor, Tibshirani, Robert, and Friedman, Jerome, 2009,
The elements of statistical learning - Data mining, inference, and
prediction (2nd ed.): New York, Springer Science + Business Media, LLC, 745 p.

Shalizi, C.R., 2016, Advanced data analysis from an elementary point of
view: Draft book manuscript publicly available at
\url{http://www.stat.cmu.edu/~cshalizi/ADAfaEPoV/}
}

