% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TotalTonnagePdf.R
\name{plot.TotalTonnagePdf}
\alias{plot.TotalTonnagePdf}
\title{Plot the univariate, marginal pdfs and ccdfs for the
total ore and resource tonnages in
all undiscovered deposits within the permissive tract}
\usage{
\method{plot}{TotalTonnagePdf}(object, adjust = 2, isUsgsStyle = TRUE)
}
\arguments{
\item{object}{An object of class "TotalTonnagePdf".}

\item{adjust}{Smoothing used to calculate the pdfs.}

\item{isUsgsStyle}{Make the plot format similar to the U.S. Geological Survey style}
}
\description{
Plot the unvariate, marginal probability density
functions (pdfs) and complementary cumulative distribution functions
(ccdfs)
for the total ore and resource tonnages in all undiscovered
deposits within the permissive tract.
}
\details{
Argument adjust is scaling applied to the bandwidth of the kernel density
estimate, which is calculated with R function density. As adjust increases,
the pdf becomes smoother.
}
\examples{
oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleGatm)
oGradePdf <- GradePdf(ExampleGatm)
oSimulation <- Simulation(oPmf, oTonPdf, oGradePdf)
oTotalTonPdf <- TotalTonnagePdf(oSimulation, oPmf, oTonPdf, oGradePdf)
plot(oTotalTonPdf)

oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleTm)
oSimulation <- Simulation(oPmf, oTonPdf)
oTotalTonPdf <- TotalTonnagePdf(oSimulation, oPmf, oTonPdf)
plot(oTotalTonPdf)

}

