% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TotalTonnagePdf.R
\name{plotMarginals}
\alias{plotMarginals}
\title{Plot the marginal distributions for the
total ore and resource tonnages in all undiscovered deposits
within the permissive tract}
\usage{
plotMarginals(object, nPlotSamples = 1000, isUsgsStyle = TRUE)
}
\arguments{
\item{object}{An object of class "TotalTonnagePdf".}

\item{nPlotSamples}{Number of samples that represent the pdf in the plots.}

\item{isUsgsStyle}{Make the plot format similar to the U.S. Geological Survey style}
}
\description{
Plot the univariate and bivariate marginal distributions,
for the total ore and resource tonnages
in all undiscovered deposit within the permssive tract.
}
\details{
The plot is a matrix with three parts: the plots in the upper triangle,
the plots along the diagonal, and the plots in the lower triangle. In the
upper triangle are crossplots of the ore and resource tonnages, showing the
bivariate marginal distributions. Along the diagonal are histograms,
showing the univariate marginal distributions.
In the lower triangle are contour plots, showing the bivariate marginal
distributions. The plots in the lower triangle have corresponding plots
in the upper triangle.

Above the matrix of plots is text specifying the probability that
the tonnages are zero.

Recall that the pdf is implicitly specified by random samples. Consequently,
the plots are generated from \code{nPlotSamples} random
samples. A suitable value for parameter \code{nPlotSamples} is
approximately 1000.

If a tonnage model is used for the assessment, then there is only one
tonnage, which is contained metal tonnage. In this case, there
is only one plot in the matrix, which is the histogram for the
contained metal tonnage.
}
\examples{
oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleGatm)
oGradePdf <- GradePdf(ExampleGatm)
oSimulation <- Simulation(oPmf, oTonPdf, oGradePdf)
oTotalTonPdf <- TotalTonnagePdf(oSimulation, oPmf, oTonPdf, oGradePdf)
plotMarginals(oTotalTonPdf)

oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleTm)
oSimulation <- Simulation(oPmf, oTonPdf)
oTotalTonPdf <- TotalTonnagePdf(oSimulation, oPmf, oTonPdf)
plotMarginals(oTotalTonPdf)

}

