% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TotalTonnagePdf.R
\name{summary.TotalTonnagePdf}
\alias{summary.TotalTonnagePdf}
\title{Summarize the total ore and resource
tonnages in all undiscovered deposits within the permissive tract}
\usage{
\method{summary}{TotalTonnagePdf}(object, nDigits = 3)
}
\arguments{
\item{object}{An object of class "TotalTonnagePdf"}

\item{nDigits}{Number of signficant digits.}
}
\description{
The summary has two parts. The first part comprises point
statistics for the univariate, marginal probability density
functions (pdfs) for the
total ore and resource tonnages in all undiscovered deposits within the
permissive
tract. The second part is a comparison between sets of statistics. One
set is calculated from
the multivariate pdf that represents the ore and resourc tonnages. The
other set is calculated with analytic formulas.
}
\details{
The point statistics are the
0.05, 0.10, 0.25, 0.50, 0.75, 0.90, and 0.95 quantiles,
the arithmetic mean, the probability of zero tonnage,
and the probability of exceeding the arithmetic mean.

The statistics used for the comparison are the mean vector, the
standard deviation vector, and the correlation coefficients.
Differences between
corresponding statistics are common but should be small.
}
\examples{
oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleGatm)
oGradePdf <- GradePdf(ExampleGatm)
oSimulation <- Simulation(oPmf, oTonPdf, oGradePdf)
oTotalTonPdf <- TonnagePtPdf(oSimulation, oPmf, oTonPdf, oGradePdf)
summary(oTotalTonPdf)

oPmf <- NDepositsPmf("NegBinomial", list(nDepEst = ExampleDepEst4))
oTonPdf <- TonnagePdf(ExampleTm)
oSimulation <- Simulation(oPmf, oTonPdf)
oTotalTonPdf <- TonnagePtPdf(oSimulation, oPmf, oTonPdf)
summary(oTotalTonPdf)

}

